owenb 2003/09/02 02:35:46
Modified: java/src/org/apache/wsif/base Tag:
WSIF_2_0-uses-wsdl4j-1_4-patches
WSIFDefaultPort.java
Log:
Rename portContext back to context
Revision Changes Path
No revision
No revision
1.8.4.2 +8 -8 xml-axis-wsif/java/src/org/apache/wsif/base/WSIFDefaultPort.java
Index: WSIFDefaultPort.java
===================================================================
RCS file:
/home/cvs/xml-axis-wsif/java/src/org/apache/wsif/base/WSIFDefaultPort.java,v
retrieving revision 1.8.4.1
retrieving revision 1.8.4.2
diff -u -r1.8.4.1 -r1.8.4.2
--- WSIFDefaultPort.java 1 Sep 2003 13:00:30 -0000 1.8.4.1
+++ WSIFDefaultPort.java 2 Sep 2003 09:35:46 -0000 1.8.4.2
@@ -79,7 +79,7 @@
public abstract class WSIFDefaultPort implements WSIFPort {
private static final long serialVersionUID = 1L;
- protected WSIFMessage portContext;
+ protected WSIFMessage context;
public void close() throws WSIFException {
Trc.entry(this);
@@ -187,14 +187,14 @@
public WSIFMessage getContext() throws WSIFException {
Trc.entry(this);
WSIFMessage contextCopy;
- if (this.portContext == null) {
+ if (this.context == null) {
// really this should call getContext on the WSIFService but
// theres no reference to that so WSIFService must call setContext
// on any WSIFPorts it creates.
contextCopy = new WSIFDefaultMessage();
} else {
try {
- contextCopy = (WSIFMessage) this.portContext.clone();
+ contextCopy = (WSIFMessage) this.context.clone();
} catch (CloneNotSupportedException e) {
throw new WSIFException(
"CloneNotSupportedException cloning context", e);
@@ -206,14 +206,14 @@
/**
* Sets the context information for this WSIFPort.
* @param WSIFMessage the new context information
*/
- public void setContext(WSIFMessage context) {
- Trc.entry(this, context);
- if (context == null) {
+ public void setContext(WSIFMessage newContext) {
+ Trc.entry(this, newContext);
+ if (newContext == null) {
throw new IllegalArgumentException("context must not be null");
}
- this.portContext = context;
+ this.context = newContext;
Trc.exit(null);
}
@@ -206,14 +206,14 @@
/**
* Sets the context information for this WSIFPort.
- * @param WSIFMessage the new context information
+ * @param newContext the new context information
*/